import { InjectionToken } from '@angular/core';
import { SisenseContextService, WidgetProps } from '@sisense/sdk-ui-angular';
import { AiContextProviderProps, ChatRestApi, GetNlqResultParams, GetQueryRecommendationsParams, QueryRecommendation as QueryRecommendationPreact, UseGetNlgInsightsParams } from '@sisense/sdk-ui-preact/ai';
import * as i0 from "@angular/core";
export interface AiContextConfig extends Omit<AiContextProviderProps, 'children'> {
}
export interface GetNlgInsightsParams extends Omit<UseGetNlgInsightsParams, 'enabled'> {
}
/**
 * {@inheritDoc @sisense/sdk-ui!QueryRecommendation}
 */
export interface QueryRecommendation extends Omit<QueryRecommendationPreact, 'widgetProps'> {
    /**
     * {@inheritDoc @sisense/sdk-ui!QueryRecommendation.widgetProps}
     */
    widgetProps?: WidgetProps;
}
/**
 * Token used to inject {@link AiContextConfig} into your application.
 *
 * @example
 * Example of importing {@link SdkAiModule} and injecting {@link AiContextConfig} into your application,
 * along with importing dependency {@link SdkUiModule} and injecting {@link SisenseContextConfig} to connect to a Sisense instance:
 *
 * ```ts
 * import { SdkUiModule, SisenseContextConfig } from '@sisense/sdk-ui-angular';
 * import { SdkAiModule, AI_CONTEXT_CONFIG_TOKEN, AiContextConfig } from '@sisense/sdk-ui-angular/ai';
 *
 * const AI_CONTEXT_CONFIG: AiContextConfig = {
 *   volatile: true,
 * };
 * const SISENSE_CONTEXT_CONFIG: SisenseContextConfig = {
 *   url: "<instance url>", // replace with the URL of your Sisense instance
 *   token: "<api token>", // replace with the API token of your user account
 *   defaultDataSource: DM.DataSource,
 * };
 *
 * @NgModule({
 *   imports: [
 *     BrowserModule,
 *     SdkUiModule,
 *     SdkAiModule,
 *   ],
 *   declarations: [AppComponent],
 *   providers: [
 *     { provide: AI_CONTEXT_CONFIG_TOKEN, useValue: AI_CONTEXT_CONFIG },
 *     { provide: SISENSE_CONTEXT_CONFIG_TOKEN, useValue: SISENSE_CONTEXT_CONFIG },
 *   ],
 *   bootstrap: [AppComponent],
 * })
 * ```
 * @group Generative AI
 */
export declare const AI_CONTEXT_CONFIG_TOKEN: InjectionToken<AiContextConfig>;
/**
 * Service for working with Sisense Fusion Generative AI.
 *
 * @group Generative AI
 */
export declare class AiService {
    private sisenseContextService;
    private apiPromise;
    constructor(sisenseContextService: SisenseContextService, aiContextConfig?: AiContextConfig);
    /** @internal */
    getApi(): Promise<ChatRestApi>;
    /**
     * Fetches an analysis of the provided query using natural language generation (NLG).
     * Specifying NLG parameters is similar to providing parameters to the {@link QueryService.executeQuery} service method, using dimensions, measures, and filters.
     *
     * @param params - Parameters for getting NLG insights
     * @returns NLG insights text summary
     */
    getNlgInsights(params: GetNlgInsightsParams): Promise<string | undefined>;
    /**
     * Fetches recommended questions for a data model or perspective.
     *
     * @param params - Parameters for recommendations
     * @returns An array of objects, each containing recommended question text and its corresponding `widgetProps`
     * @beta
     */
    getQueryRecommendations(params: GetQueryRecommendationsParams): Promise<QueryRecommendation[]>;
    /**
     * Executes a natural language query (NLQ) against a data model or perspective
     *
     * @param params - NLQ query parameters
     * @returns The result as WidgetProps
     * @beta
     */
    getNlqResult(params: GetNlqResultParams): Promise<WidgetProps | undefined>;
    static ɵfac: i0.ɵɵFactoryDeclaration<AiService, [null, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<AiService>;
}
