import * as i0 from '@angular/core';
import { InjectionToken, Injectable, Optional, Inject, Component, ViewChild, Input, NgModule } from '@angular/core';
import * as i1 from '@sisense/sdk-ui-angular';
import { TrackableService, createSisenseContextConnector, createThemeContextConnector, SdkUiModule } from '@sisense/sdk-ui-angular';
import { DataObserver, ComponentAdapter } from '@sisense/sdk-ui-preact';
import { CustomAiContextProvider, ChatRestApi, prepareGetNlgInsightsPayload, DEFAULT_RECOMMENDATIONS_COUNT, widgetComposer, prepareGetNlqResultPayload, Chatbot, GetNlgInsights } from '@sisense/sdk-ui-preact/ai';
import { __decorate } from 'tslib';
import { CommonModule } from '@angular/common';

/**
 * Creates AI context connector
 *
 * @param aiService - The AI service
 * @internal
 */
const createAiContextConnector = (aiService) => {
    const propsObserver = new DataObserver();
    aiService
        .getApi()
        .then((api) => propsObserver.setValue({
        context: {
            api,
        },
    }))
        .catch((error) => propsObserver.setValue({
        error,
    }));
    return {
        propsObserver,
        providerComponent: CustomAiContextProvider,
    };
};

const rootId = 'preact';
const template = `
    <div #${rootId} class="csdk-full-size-container"></div>
`;
const styles = [
    `.csdk-full-size-container {
        width: 100%;
        height: 100%;
    }`,
];

/**
 * Token used to inject {@link AiContextConfig} into your application.
 *
 * @example
 * Example of importing {@link SdkAiModule} and injecting {@link AiContextConfig} into your application,
 * along with importing dependency {@link SdkUiModule} and injecting {@link SisenseContextConfig} to connect to a Sisense instance:
 *
 * ```ts
 * import { SdkUiModule, SisenseContextConfig } from '@sisense/sdk-ui-angular';
 * import { SdkAiModule, AI_CONTEXT_CONFIG_TOKEN, AiContextConfig } from '@sisense/sdk-ui-angular/ai';
 *
 * const AI_CONTEXT_CONFIG: AiContextConfig = {
 *   volatile: true,
 * };
 * const SISENSE_CONTEXT_CONFIG: SisenseContextConfig = {
 *   url: "<instance url>", // replace with the URL of your Sisense instance
 *   token: "<api token>", // replace with the API token of your user account
 *   defaultDataSource: DM.DataSource,
 * };
 *
 * @NgModule({
 *   imports: [
 *     BrowserModule,
 *     SdkUiModule,
 *     SdkAiModule,
 *   ],
 *   declarations: [AppComponent],
 *   providers: [
 *     { provide: AI_CONTEXT_CONFIG_TOKEN, useValue: AI_CONTEXT_CONFIG },
 *     { provide: SISENSE_CONTEXT_CONFIG_TOKEN, useValue: SISENSE_CONTEXT_CONFIG },
 *   ],
 *   bootstrap: [AppComponent],
 * })
 * ```
 * @group Generative AI
 */
const AI_CONTEXT_CONFIG_TOKEN = new InjectionToken('AI Context Config');
/**
 * Service for working with Sisense Fusion Generative AI.
 *
 * @group Generative AI
 */
let AiService = class AiService {
    constructor(sisenseContextService, aiContextConfig) {
        this.sisenseContextService = sisenseContextService;
        this.apiPromise = this.sisenseContextService
            .getApp()
            .then((app) => new ChatRestApi(app.httpClient, aiContextConfig?.volatile));
    }
    /** @internal */
    getApi() {
        return this.apiPromise;
    }
    /**
     * Fetches an analysis of the provided query using natural language generation (NLG).
     * Specifying NLG parameters is similar to providing parameters to the {@link QueryService.executeQuery} service method, using dimensions, measures, and filters.
     *
     * @param params - Parameters for getting NLG insights
     * @returns NLG insights text summary
     */
    async getNlgInsights(params) {
        const api = await this.getApi();
        const payload = prepareGetNlgInsightsPayload(params);
        return api.ai
            .getNlgInsights(payload)
            .then((response) => response?.data?.answer);
    }
    /**
     * Fetches recommended questions for a data model or perspective.
     *
     * @param params - Parameters for recommendations
     * @returns An array of objects, each containing recommended question text and its corresponding `widgetProps`
     * @beta
     */
    async getQueryRecommendations(params) {
        const api = await this.getApi();
        const { contextTitle, count, enableAxisTitlesInWidgetProps } = params;
        const recCount = count ?? DEFAULT_RECOMMENDATIONS_COUNT;
        const rawRecommendations = (await api.ai.getQueryRecommendations(contextTitle, { numOfRecommendations: recCount })) ||
            [];
        return rawRecommendations.map((recommendation) => ({
            ...recommendation,
            widgetProps: recommendation.jaql
                ? widgetComposer.toWidgetProps(recommendation, {
                    useCustomizedStyleOptions: enableAxisTitlesInWidgetProps,
                })
                : undefined,
        }));
    }
    /**
     * Executes a natural language query (NLQ) against a data model or perspective
     *
     * @param params - NLQ query parameters
     * @returns The result as WidgetProps
     * @beta
     */
    async getNlqResult(params) {
        const { contextTitle, request } = prepareGetNlqResultPayload(params);
        const api = await this.getApi();
        const data = await api?.ai.getNlqResult(contextTitle, request);
        return data
            ? widgetComposer.toWidgetProps(data, {
                useCustomizedStyleOptions: params.enableAxisTitlesInWidgetProps || false,
            })
            : undefined;
    }
};
AiService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: AiService, deps: [{ token: i1.SisenseContextService }, { token: AI_CONTEXT_CONFIG_TOKEN, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
AiService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: AiService, providedIn: 'root' });
AiService = __decorate([
    TrackableService(['getNlgInsights', 'getQueryRecommendations'])
], AiService);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: AiService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: function () { return [{ type: i1.SisenseContextService }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [AI_CONTEXT_CONFIG_TOKEN]
                }] }]; } });

/**
 * An Angular component that renders a chatbot with data topic selection.
 *
 * @example
 * An example of using the `ChatbotComponent`:
 *
 * ```html
<!--Component HTML template in example.component.html-->
<csdk-chatbot
  [width]="chatbot.width"
  [height]="chatbot.height"
  [config]="chatbot.config"
/>
 * ```
 *
 * ```ts
// Component behavior in example.component.ts
import { Component } from '@angular/core';

@Component({
  selector: 'example',
  templateUrl: './example.component.html',
  styleUrls: ['./example.component.scss'],
})
export class ExampleComponent {
  chatbot = {
    width: '500px',
    height: '700px',
    config: {
      numOfRecommendations: 5,
    },
  };
}
 * ```
 *
 * <img src="media://angular-chatbot-example.png" width="500px" />
 * @group Generative AI
 */
class ChatbotComponent {
    /**
     * Constructor for the `ChatbotComponent`.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     * @param aiService - AI service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService, 
    /**
     * AI service
     *
     * @category Constructor
     */
    aiService) {
        this.sisenseContextService = sisenseContextService;
        this.themeService = themeService;
        this.aiService = aiService;
        this.componentAdapter = new ComponentAdapter(Chatbot, [
            createSisenseContextConnector(this.sisenseContextService),
            createThemeContextConnector(this.themeService),
            createAiContextConnector(this.aiService),
        ]);
    }
    /**
     * @internal
     */
    ngAfterViewInit() {
        this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
    }
    /**
     * @internal
     */
    ngOnChanges() {
        if (this.preactRef) {
            this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
        }
    }
    getPreactComponentProps() {
        return {
            width: this.width,
            height: this.height,
            config: this.config,
        };
    }
    /**
     * @internal
     */
    ngOnDestroy() {
        this.componentAdapter.destroy();
    }
}
ChatbotComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ChatbotComponent, deps: [{ token: i1.SisenseContextService }, { token: i1.ThemeService }, { token: AiService }], target: i0.ɵɵFactoryTarget.Component });
ChatbotComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: ChatbotComponent, selector: "csdk-chatbot", inputs: { width: "width", height: "height", config: "config" }, viewQueries: [{ propertyName: "preactRef", first: true, predicate: ["preact"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "\n    <div #preact class=\"csdk-full-size-container\"></div>\n", isInline: true, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: ChatbotComponent, decorators: [{
            type: Component,
            args: [{ selector: 'csdk-chatbot', template: template, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: i1.SisenseContextService }, { type: i1.ThemeService }, { type: AiService }]; }, propDecorators: { preactRef: [{
                type: ViewChild,
                args: [rootId]
            }], width: [{
                type: Input
            }], height: [{
                type: Input
            }], config: [{
                type: Input
            }] } });

/**
 * An Angular component that fetches and displays a collapsible analysis of the provided query using natural language generation (NLG).
 * Specifying NLG parameters is similar to providing parameters to the {@link QueryService.executeQuery} service method, using dimensions, measures, and filters.
 *
 * @example
 * An example of using the `GetNlgInsightsComponent`:
 *
 * ```html
<!--Component HTML template in example.component.html-->
<csdk-get-nlg-insights
  [dataSource]="nlgParams.dataSource"
  [dimensions]="nlgParams.dimensions"
  [measures]="nlgParams.measures"
/>
 * ```
 *
 * ```ts
// Component behavior in example.component.ts
import { Component } from '@angular/core';
import { measureFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';

@Component({
  selector: 'example',
  templateUrl: './example.component.html',
  styleUrls: ['./example.component.scss'],
})
export class ExampleComponent {
  nlgParams = {
    dataSource: DM.DataSource.title,
    dimensions: [DM.Divisions.Divison_name],
    measures: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
  };
}
 * ```
 *
 * <img src="media://angular-get-nlg-insights-example.png" width="700px" />
 * @group Generative AI
 */
class GetNlgInsightsComponent {
    /**
     * Constructor for the `GetNlgInsightsProps`.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     * @param aiService - AI service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService, 
    /**
     * AI service
     *
     * @category Constructor
     */
    aiService) {
        this.sisenseContextService = sisenseContextService;
        this.themeService = themeService;
        this.aiService = aiService;
        this.componentAdapter = new ComponentAdapter(GetNlgInsights, [
            createSisenseContextConnector(this.sisenseContextService),
            createThemeContextConnector(this.themeService),
            createAiContextConnector(this.aiService),
        ]);
    }
    /**
     * @internal
     */
    ngAfterViewInit() {
        this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
    }
    /**
     * @internal
     */
    ngOnChanges() {
        if (this.preactRef) {
            this.componentAdapter.render(this.preactRef.nativeElement, this.getPreactComponentProps());
        }
    }
    getPreactComponentProps() {
        return {
            dataSource: this.dataSource,
            dimensions: this.dimensions,
            measures: this.measures,
            filters: this.filters,
            verbosity: this.verbosity,
        };
    }
    /**
     * @internal
     */
    ngOnDestroy() {
        this.componentAdapter.destroy();
    }
}
GetNlgInsightsComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: GetNlgInsightsComponent, deps: [{ token: i1.SisenseContextService }, { token: i1.ThemeService }, { token: AiService }], target: i0.ɵɵFactoryTarget.Component });
GetNlgInsightsComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: GetNlgInsightsComponent, selector: "csdk-get-nlg-insights", inputs: { dataSource: "dataSource", dimensions: "dimensions", measures: "measures", filters: "filters", verbosity: "verbosity" }, viewQueries: [{ propertyName: "preactRef", first: true, predicate: ["preact"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "\n    <div #preact class=\"csdk-full-size-container\"></div>\n", isInline: true, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: GetNlgInsightsComponent, decorators: [{
            type: Component,
            args: [{ selector: 'csdk-get-nlg-insights', template: template, styles: [".csdk-full-size-container{width:100%;height:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: i1.SisenseContextService }, { type: i1.ThemeService }, { type: AiService }]; }, propDecorators: { preactRef: [{
                type: ViewChild,
                args: [rootId]
            }], dataSource: [{
                type: Input
            }], dimensions: [{
                type: Input
            }], measures: [{
                type: Input
            }], filters: [{
                type: Input
            }], verbosity: [{
                type: Input
            }] } });

/* eslint-disable import/no-extraneous-dependencies */
/**
 * SDK AI Module, which is a container for generative AI components and services.
 *
 * @example
 * Example of importing {@link SdkAiModule} and injecting {@link AiContextConfig} into your application,
 * along with importing dependency {@link SdkUiModule} and injecting {@link SisenseContextConfig} to connect to a Sisense instance:
 *
 * ```ts
 * import { SdkUiModule, SisenseContextConfig } from '@sisense/sdk-ui-angular';
 * import { SdkAiModule, AI_CONTEXT_CONFIG_TOKEN, AiContextConfig } from '@sisense/sdk-ui-angular/ai';
 *
 * const AI_CONTEXT_CONFIG: AiContextConfig = {
 *   volatile: true,
 * };
 * const SISENSE_CONTEXT_CONFIG: SisenseContextConfig = {
 *   url: "<instance url>", // replace with the URL of your Sisense instance
 *   token: "<api token>", // replace with the API token of your user account
 *   defaultDataSource: DM.DataSource,
 * };
 *
 * @NgModule({
 *   imports: [
 *     BrowserModule,
 *     SdkUiModule,
 *     SdkAiModule,
 *   ],
 *   declarations: [AppComponent],
 *   providers: [
 *     { provide: AI_CONTEXT_CONFIG_TOKEN, useValue: AI_CONTEXT_CONFIG },
 *     { provide: SISENSE_CONTEXT_CONFIG_TOKEN, useValue: SISENSE_CONTEXT_CONFIG },
 *   ],
 *   bootstrap: [AppComponent],
 * })
 * ```
 * @group Generative AI
 */
class SdkAiModule {
    constructor() {
        console.log('SdkAiModule loaded');
    }
}
SdkAiModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: SdkAiModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
SdkAiModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: SdkAiModule, declarations: [ChatbotComponent, GetNlgInsightsComponent], imports: [CommonModule, SdkUiModule], exports: [ChatbotComponent, GetNlgInsightsComponent] });
SdkAiModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: SdkAiModule, imports: [CommonModule, SdkUiModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: SdkAiModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [ChatbotComponent, GetNlgInsightsComponent],
                    imports: [CommonModule, SdkUiModule],
                    exports: [ChatbotComponent, GetNlgInsightsComponent],
                    providers: [],
                }]
        }], ctorParameters: function () { return []; } });

// This file re-exports common types/utils from @sisense/sdk-ui-preact/ai

/**
 * Public API Surface of @sisense/sdk-ui-angular/ai
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AI_CONTEXT_CONFIG_TOKEN, AiService, ChatbotComponent, GetNlgInsightsComponent, SdkAiModule };
//# sourceMappingURL=sisense-sdk-ui-angular-ai.mjs.map
