import { EventEmitter } from '@angular/core';
import { type AreaChartProps as AreaChartPropsPreact } from '@sisense/sdk-ui-preact';
import { type ChartType } from '../../sdk-ui-core-exports';
import { RegularChartEventProps, WithoutPreactChartEventProps } from '../../types/chart-event-props';
import { DataPointEvent, DataPointsEvent } from '../../types/data-point';
import * as i0 from "@angular/core";
/**
 * Props of the {@link AreaChartComponent} component.
 */
export interface AreaChartProps extends WithoutPreactChartEventProps<AreaChartPropsPreact>, RegularChartEventProps {
}
/**
 * A component similar to a {@link LineChartComponent},
 * but with filled in areas under each line and an option to display them as stacked.
 *
 * @example
 * ```html
 *    <csdk-area-chart
 *      [dataSet]="chart.dataSet"
 *      [dataOptions]="chart.dataOptions"
 *      [highlights]="filters"
 *      [beforeRender]="onBeforeRender"
 *      (dataPointClick)="logArguments($event)"
 *      (dataPointContextMenu)="logArguments($event)"
 *      (dataPointsSelect)="logArguments($event)"
 *    />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory, Filter } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';
import type { ChartType } from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  chart = {
    chartType: 'column' as ChartType,
    dataSet: DM.DataSource,
    dataOptions: {
      category: [DM.Divisions.Divison_name],
      value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
      breakBy: [],
    },
  };

  onBeforeRender(options: any) {
    console.log('beforeRender');
    console.log(options);
    return options;
  }

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-area-chart-example.png" width="800px" />
 * @group Charts
 */
export declare class AreaChartComponent {
    /**
     * {@inheritDoc @sisense/sdk-ui!AreaChartProps.dataSet}
     *
     * @category Data
     */
    dataSet: AreaChartProps['dataSet'];
    /**
     * {@inheritDoc @sisense/sdk-ui!AreaChartProps.dataOptions}
     *
     * @category Chart
     */
    dataOptions: AreaChartProps['dataOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!AreaChartProps.filters}
     *
     * @category Data
     */
    filters: AreaChartProps['filters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!AreaChartProps.highlights}
     *
     * @category Data
     */
    highlights: AreaChartProps['highlights'];
    /**
     * {@inheritDoc @sisense/sdk-ui!AreaChartProps.styleOptions}
     *
     * @category Chart
     */
    styleOptions: AreaChartProps['styleOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!AreaChartProps.onBeforeRender}
     *
     * @category Callbacks
     */
    beforeRender: AreaChartProps['beforeRender'];
    /**
     * {@inheritDoc  @sisense/sdk-ui!AreaChartProps.onDataReady}
     *
     * @category Callbacks
     */
    dataReady: AreaChartProps['dataReady'];
    /**
     * {@inheritDoc @sisense/sdk-ui!AreaChartProps.onDataPointClick}
     *
     * @category Callbacks
     */
    dataPointClick: EventEmitter<DataPointEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!AreaChartProps.onDataPointContextMenu}
     *
     * @category Callbacks
     */
    dataPointContextMenu: EventEmitter<DataPointEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!AreaChartProps.onDataPointsSelected}
     *
     * @category Callbacks
     */
    dataPointsSelect: EventEmitter<DataPointsEvent>;
    /** @internal */
    chartType: ChartType;
    static ɵfac: i0.ɵɵFactoryDeclaration<AreaChartComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AreaChartComponent, "csdk-area-chart", never, { "dataSet": "dataSet"; "dataOptions": "dataOptions"; "filters": "filters"; "highlights": "highlights"; "styleOptions": "styleOptions"; "beforeRender": "beforeRender"; "dataReady": "dataReady"; }, { "dataPointClick": "dataPointClick"; "dataPointContextMenu": "dataPointContextMenu"; "dataPointsSelect": "dataPointsSelect"; }, never, never, false, never>;
}
