import { EventEmitter } from '@angular/core';
import { type AreaRangeChartProps as AreaRangeChartPropsPreact } from '@sisense/sdk-ui-preact';
import { type ChartType } from '../../sdk-ui-core-exports';
import { RegularChartEventProps, WithoutPreactChartEventProps } from '../../types/chart-event-props';
import { DataPointEvent, DataPointsEvent } from '../../types/data-point';
import * as i0 from "@angular/core";
/**
 * Props of the {@link AreaRangeChartComponent}.
 */
export interface AreaRangeChartProps extends WithoutPreactChartEventProps<AreaRangeChartPropsPreact>, RegularChartEventProps {
}
/**
 * A component that displays a range of data over a given time period or across multiple categories.
 * It is particularly useful for visualizing the minimum and maximum values in a dataset, along with
 * the area between these values.
 *
 * @example
 * ```html
 *    <csdk-area-range-chart
 *      [dataSet]="chart.dataSet"
 *      [dataOptions]="chart.dataOptions"
 *      [highlights]="filters"
 *      [beforeRender]="onBeforeRender"
 *      (dataPointClick)="logArguments($event)"
 *      (dataPointContextMenu)="logArguments($event)"
 *      (dataPointsSelect)="logArguments($event)"
 *    />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory, Filter } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';
import type { ChartType, RangeChartDataOptions } from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  chart = {
    chartType: 'arearange' as ChartType,
    dataSet: DM.DataSource,
    dataOptions: {
      category: [DM.Admissions.Admission_Time.Years],
      value: [
        {
            title: 'Admission Cost Range',
            upperBound: measureFactory.multiply(
              measureFactory.sum(DM.Admissions.Cost_of_admission, 'Lower Admission'),
              0.6,
            ),
            lowerBound: measureFactory.multiply(
              measureFactory.sum(DM.Admissions.Cost_of_admission, 'Upper Admission'),
              1.4,
             ),
        }
      ],
      breakBy: [],
    } as RangeChartDataOptions,
  };

  onBeforeRender(options: any) {
    console.log('beforeRender');
    console.log(options);
    return options;
  }

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-area-range-chart-example.png" width="800px" />
 * @group Charts
 */
export declare class AreaRangeChartComponent {
    /**
     * {@inheritDoc @sisense/sdk-ui!AreaRangeChartProps.dataSet}
     *
     * @category Data
     */
    dataSet: AreaRangeChartProps['dataSet'];
    /**
     * {@inheritDoc @sisense/sdk-ui!AreaRangeChartProps.dataOptions}
     *
     * @category Chart
     */
    dataOptions: AreaRangeChartProps['dataOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!AreaRangeChartProps.filters}
     *
     * @category Data
     */
    filters: AreaRangeChartProps['filters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!AreaRangeChartProps.highlights}
     *
     * @category Data
     */
    highlights: AreaRangeChartProps['highlights'];
    /**
     * {@inheritDoc @sisense/sdk-ui!AreaRangeChartProps.styleOptions}
     *
     * @category Chart
     */
    styleOptions: AreaRangeChartProps['styleOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!AreaRangeChartProps.onBeforeRender}
     *
     * @category Callbacks
     */
    beforeRender: AreaRangeChartProps['beforeRender'];
    /**
     * {@inheritDoc  @sisense/sdk-ui!AreaRangeChartProps.onDataReady}
     *
     * @category Callbacks
     */
    dataReady: AreaRangeChartProps['dataReady'];
    /**
     * {@inheritDoc @sisense/sdk-ui!AreaRangeChartProps.onDataPointClick}
     *
     * @category Callbacks
     */
    dataPointClick: EventEmitter<DataPointEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!AreaRangeChartProps.onDataPointContextMenu}
     *
     * @category Callbacks
     */
    dataPointContextMenu: EventEmitter<DataPointEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!AreaRangeChartProps.onDataPointsSelected}
     *
     * @category Callbacks
     */
    dataPointsSelect: EventEmitter<DataPointsEvent>;
    /** @internal */
    chartType: ChartType;
    static ɵfac: i0.ɵɵFactoryDeclaration<AreaRangeChartComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AreaRangeChartComponent, "csdk-area-range-chart", never, { "dataSet": "dataSet"; "dataOptions": "dataOptions"; "filters": "filters"; "highlights": "highlights"; "styleOptions": "styleOptions"; "beforeRender": "beforeRender"; "dataReady": "dataReady"; }, { "dataPointClick": "dataPointClick"; "dataPointContextMenu": "dataPointContextMenu"; "dataPointsSelect": "dataPointsSelect"; }, never, never, false, never>;
}
