import { EventEmitter } from '@angular/core';
import { type BoxplotChartProps as BoxplotChartPropsPreact } from '@sisense/sdk-ui-preact';
import { type ChartType } from '../../sdk-ui-core-exports';
import { BoxplotChartEventProps, WithoutPreactChartEventProps } from '../../types/chart-event-props';
import { BoxplotDataPointEvent, BoxplotDataPointsEvent } from '../../types/data-point';
import * as i0 from "@angular/core";
/**
 * Props of the {@link BoxplotChartComponent}.
 */
export interface BoxplotChartProps extends WithoutPreactChartEventProps<BoxplotChartPropsPreact>, BoxplotChartEventProps {
}
/**
 * An Angular component representing data in a way that visually describes the distribution
 * variability, and center of a data set along an axis.
 *
 * @example
 * ```html
 *    <csdk-boxplot-chart
 *      [dataSet]="boxplotChart.dataSet"
 *      [dataOptions]="boxplotChart.dataOptions"
 *      [highlights]="boxplotChart.highlights"
 *      [beforeRender]="onBeforeRender"
 *      (dataPointClick)="logArguments($event)"
 *      (dataPointContextMenu)="logArguments($event)"
 *      (dataPointsSelect)="logArguments($event)"
 *    />
 * ```
 *
 * ```ts
import { Component } from '@angular/core';
import { filterFactory } from '@sisense/sdk-data';
import type { BoxplotChartDataOptions } from '@sisense/sdk-ui-angular';
import * as DM from '../../assets/sample-healthcare-model';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  boxplotChart = {
    dataSet: DM.DataSource,
    dataOptions: {
      category: [DM.Divisions.Divison_name],
      value: [DM.Admissions.TimeofStay],
      boxType: 'iqr',
      outliersEnabled: true,
    } as BoxplotChartDataOptions,
    highlights: [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])],
  };

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-boxplot-chart-example.png" width="800px" />
 * @group Charts
 */
export declare class BoxplotChartComponent {
    /**
     * {@inheritDoc @sisense/sdk-ui!BoxplotChartProps.dataSet}
     *
     * @category Data
     */
    dataSet: BoxplotChartProps['dataSet'];
    /**
     * {@inheritDoc @sisense/sdk-ui!BoxplotChartProps.dataOptions}
     *
     * @category Chart
     */
    dataOptions: BoxplotChartProps['dataOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!BoxplotChartProps.filters}
     *
     * @category Data
     */
    filters: BoxplotChartProps['filters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!BoxplotChartProps.highlights}
     *
     * @category Data
     */
    highlights: BoxplotChartProps['highlights'];
    /**
     * {@inheritDoc @sisense/sdk-ui!BoxplotChartProps.styleOptions}
     *
     * @category Chart
     */
    styleOptions: BoxplotChartProps['styleOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!BoxplotChartProps.onBeforeRender}
     *
     * @category Callbacks
     */
    beforeRender: BoxplotChartProps['beforeRender'];
    /**
     * {@inheritDoc  @sisense/sdk-ui!BoxplotChartProps.onDataReady}
     *
     * @category Callbacks
     */
    dataReady: BoxplotChartProps['dataReady'];
    /**
     * {@inheritDoc @sisense/sdk-ui!BoxplotChartProps.onDataPointClick}
     *
     * @category Callbacks
     */
    dataPointClick: EventEmitter<BoxplotDataPointEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!BoxplotChartProps.onDataPointContextMenu}
     *
     * @category Callbacks
     */
    dataPointContextMenu: EventEmitter<BoxplotDataPointEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!BoxplotChartProps.onDataPointsSelected}
     *
     * @category Callbacks
     */
    dataPointsSelect: EventEmitter<BoxplotDataPointsEvent>;
    /** @internal */
    chartType: ChartType;
    static ɵfac: i0.ɵɵFactoryDeclaration<BoxplotChartComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<BoxplotChartComponent, "csdk-boxplot-chart", never, { "dataSet": "dataSet"; "dataOptions": "dataOptions"; "filters": "filters"; "highlights": "highlights"; "styleOptions": "styleOptions"; "beforeRender": "beforeRender"; "dataReady": "dataReady"; }, { "dataPointClick": "dataPointClick"; "dataPointContextMenu": "dataPointContextMenu"; "dataPointsSelect": "dataPointsSelect"; }, never, never, false, never>;
}
