import { AfterViewInit, ElementRef, EventEmitter, OnChanges, OnDestroy } from '@angular/core';
import { type ChartProps as ChartPropsPreact } from '@sisense/sdk-ui-preact';
import { SisenseContextService } from '../../services/sisense-context.service';
import { ThemeService } from '../../services/theme.service';
import { ChartEventProps, WithoutPreactChartEventProps } from '../../types/chart-event-props';
import { ChartDataPointClickEvent, ChartDataPointContextMenuEvent, ChartDataPointsEvent } from '../../types/data-point';
import * as i0 from "@angular/core";
/**
 * Props shared across the {@link ChartComponent}.
 */
export interface ChartProps extends WithoutPreactChartEventProps<ChartPropsPreact>, ChartEventProps {
}
/**
 * An Angular component used for easily switching chart types or rendering multiple series of different chart types.
 *
 * @example
 * An example of using the `Chart` component to
 * plot a column chart of the Sample Healthcare data source hosted in a Sisense instance:
 *
 * ```html
 * <!--Component HTML template in .component.html-->
 * <csdk-chart
 *   [chartType]="chart.chartType"
 *   [dataSet]="chart.dataSet"
 *   [dataOptions]="chart.dataOptions"
 *   [filters]="chart.filters"
 *   [styleOptions]="chart.styleOptions"
 * />
 * ```
 *
 * ```ts
 * // Component behavior in .component.ts
 * chart = {
 *   chartType: 'column' as ChartType,
 *   dataSet: DM.DataSource,
 *   dataOptions: {
 *     category: [DM.Admissions.Admission_Time.Months],
 *     value: [measureFactory.count(DM.Admissions.Patient_ID, 'Total Patients')],
 *     breakBy: [],
 *   },
 *   filters: [filterFactory.members(DM.Doctors.Specialty, ['Oncology', 'Cardiology'])],
 *   styleOptions: {
 *     width: 800,
 *     height: 500,
 *     xAxis: {
 *       title: {
 *         text: 'Months',
 *         enabled: true,
 *       },
 *     },
 *     yAxis: {
 *       title: {
 *         text: 'Total Patients',
 *         enabled: true,
 *       },
 *     },
 *   },
 * };
 * ```
 *
 * <img src="media://angular-chart-example.png" width="800px" />
 * @shortDescription Common component for rendering charts of different types including table
 * @group Charts
 */
export declare class ChartComponent implements AfterViewInit, OnChanges, OnDestroy {
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService;
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService;
    /**
     * @internal
     */
    preactRef: ElementRef<HTMLDivElement>;
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartProps.chartType}
     *
     * @category Chart
     */
    chartType: ChartProps['chartType'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartProps.dataSet}
     *
     * @category Data
     */
    dataSet: ChartProps['dataSet'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartProps.dataOptions}
     *
     * @category Chart
     */
    dataOptions: ChartProps['dataOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartProps.filters}
     *
     * @category Data
     */
    filters: ChartProps['filters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartProps.highlights}
     *
     * @category Data
     */
    highlights: ChartProps['highlights'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartProps.styleOptions}
     *
     * @category Chart
     */
    styleOptions: ChartProps['styleOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartProps.onBeforeRender}
     *
     * @category Callbacks
     */
    beforeRender: ChartProps['beforeRender'];
    /**
     * {@inheritDoc  @sisense/sdk-ui!ChartProps.onDataReady}
     *
     * @category Callbacks
     */
    dataReady: ChartProps['dataReady'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartProps.onDataPointClick}
     *
     * @category Callbacks
     */
    dataPointClick: EventEmitter<ChartDataPointClickEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartProps.onDataPointContextMenu}
     *
     * @category Callbacks
     */
    dataPointContextMenu: EventEmitter<ChartDataPointContextMenuEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartProps.onDataPointsSelected}
     *
     * @category Callbacks
     */
    dataPointsSelect: EventEmitter<ChartDataPointsEvent>;
    private componentAdapter;
    /**
     * Constructor for the `Chart` component.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService);
    /**
     * @internal
     */
    ngAfterViewInit(): void;
    /**
     * @internal
     */
    ngOnChanges(): void;
    private getPreactComponentProps;
    /**
     * @internal
     */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ChartComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ChartComponent, "csdk-chart", never, { "chartType": "chartType"; "dataSet": "dataSet"; "dataOptions": "dataOptions"; "filters": "filters"; "highlights": "highlights"; "styleOptions": "styleOptions"; "beforeRender": "beforeRender"; "dataReady": "dataReady"; }, { "dataPointClick": "dataPointClick"; "dataPointContextMenu": "dataPointContextMenu"; "dataPointsSelect": "dataPointsSelect"; }, never, never, false, never>;
}
