import { EventEmitter } from '@angular/core';
import { type ColumnChartProps as ColumnChartPropsPreact } from '@sisense/sdk-ui-preact';
import { type ChartType } from '../../sdk-ui-core-exports';
import { RegularChartEventProps, WithoutPreactChartEventProps } from '../../types/chart-event-props';
import { DataPointEvent, DataPointsEvent } from '../../types/data-point';
import * as i0 from "@angular/core";
/**
 * Props of the {@link ColumnChartComponent}.
 */
export interface ColumnChartProps extends WithoutPreactChartEventProps<ColumnChartPropsPreact>, RegularChartEventProps {
}
/**
 * A component representing categorical data with vertical rectangular bars
 * whose heights are proportional to the values that they represent.
 *
 * @example
 * ```html
 *    <csdk-column-chart
 *      [dataSet]="chart.dataSet"
 *      [dataOptions]="chart.dataOptions"
 *      [highlights]="filters"
 *      [beforeRender]="onBeforeRender"
 *      (dataPointClick)="logArguments($event)"
 *      (dataPointContextMenu)="logArguments($event)"
 *      (dataPointsSelect)="logArguments($event)"
 *    />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';
import type { ChartType } from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  chart = {
    chartType: 'column' as ChartType,
    dataSet: DM.DataSource,
    dataOptions: {
      category: [DM.Divisions.Divison_name],
      value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
      breakBy: [],
    },
  };

  onBeforeRender(options: any) {
    console.log('beforeRender');
    console.log(options);
    return options;
  }

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-column-chart-example.png" width="800px" />
 * @group Charts
 */
export declare class ColumnChartComponent {
    /**
     * {@inheritDoc @sisense/sdk-ui!ColumnChartProps.dataSet}
     *
     * @category Data
     */
    dataSet: ColumnChartProps['dataSet'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ColumnChartProps.dataOptions}
     *
     * @category Chart
     */
    dataOptions: ColumnChartProps['dataOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ColumnChartProps.filters}
     *
     * @category Data
     */
    filters: ColumnChartProps['filters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ColumnChartProps.highlights}
     *
     * @category Data
     */
    highlights: ColumnChartProps['highlights'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ColumnChartProps.styleOptions}
     *
     * @category Chart
     */
    styleOptions: ColumnChartProps['styleOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ColumnChartProps.onBeforeRender}
     *
     * @category Callbacks
     */
    beforeRender: ColumnChartProps['beforeRender'];
    /**
     * {@inheritDoc  @sisense/sdk-ui!ColumnChartProps.onDataReady}
     *
     * @category Callbacks
     */
    dataReady: ColumnChartProps['dataReady'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ColumnChartProps.onDataPointClick}
     *
     * @category Callbacks
     */
    dataPointClick: EventEmitter<DataPointEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!ColumnChartProps.onDataPointContextMenu}
     *
     * @category Callbacks
     */
    dataPointContextMenu: EventEmitter<DataPointEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!ColumnChartProps.onDataPointsSelected}
     *
     * @category Callbacks
     */
    dataPointsSelect: EventEmitter<DataPointsEvent>;
    /** @internal */
    chartType: ChartType;
    static ɵfac: i0.ɵɵFactoryDeclaration<ColumnChartComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ColumnChartComponent, "csdk-column-chart", never, { "dataSet": "dataSet"; "dataOptions": "dataOptions"; "filters": "filters"; "highlights": "highlights"; "styleOptions": "styleOptions"; "beforeRender": "beforeRender"; "dataReady": "dataReady"; }, { "dataPointClick": "dataPointClick"; "dataPointContextMenu": "dataPointContextMenu"; "dataPointsSelect": "dataPointsSelect"; }, never, never, false, never>;
}
