import { EventEmitter } from '@angular/core';
import { type FunnelChartProps as FunnelChartPropsPreact } from '@sisense/sdk-ui-preact';
import { type ChartType } from '../../sdk-ui-core-exports';
import { RegularChartEventProps, WithoutPreactChartEventProps } from '../../types/chart-event-props';
import { DataPointEvent, DataPointsEvent } from '../../types/data-point';
import * as i0 from "@angular/core";
/**
 * Props of the {@link FunnelChartComponent}.
 */
export interface FunnelChartProps extends WithoutPreactChartEventProps<FunnelChartPropsPreact>, RegularChartEventProps {
}
/**
 * A component representing data progressively decreasing in size or quantity through a funnel shape.
 *
 * @example
 * ```html
 *    <csdk-funnel-chart
 *      [dataSet]="chart.dataSet"
 *      [dataOptions]="chart.dataOptions"
 *      [highlights]="filters"
 *      [beforeRender]="onBeforeRender"
 *      (dataPointClick)="logArguments($event)"
 *      (dataPointContextMenu)="logArguments($event)"
 *      (dataPointsSelect)="logArguments($event)"
 *    />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory, Filter } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';
import type { ChartType } from '@sisense/sdk-ui-angular';
@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  chart = {
    chartType: 'column' as ChartType,
    dataSet: DM.DataSource,
    dataOptions: {
      category: [DM.Divisions.Divison_name],
      value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
      breakBy: [],
    },
  };

  onBeforeRender(options: any) {
    console.log('beforeRender');
    console.log(options);
    return options;
  }

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-funnel-chart-example.png" width="800px" />
 * @group Charts
 */
export declare class FunnelChartComponent {
    /**
     * {@inheritDoc @sisense/sdk-ui!FunnelChartProps.dataSet}
     *
     * @category Data
     */
    dataSet: FunnelChartProps['dataSet'];
    /**
     * {@inheritDoc @sisense/sdk-ui!FunnelChartProps.dataOptions}
     *
     * @category Chart
     */
    dataOptions: FunnelChartProps['dataOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!FunnelChartProps.filters}
     *
     * @category Data
     */
    filters: FunnelChartProps['filters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!FunnelChartProps.highlights}
     *
     * @category Data
     */
    highlights: FunnelChartProps['highlights'];
    /**
     * {@inheritDoc @sisense/sdk-ui!FunnelChartProps.styleOptions}
     *
     * @category Chart
     */
    styleOptions: FunnelChartProps['styleOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!FunnelChartProps.onBeforeRender}
     *
     * @category Callbacks
     */
    beforeRender: FunnelChartProps['beforeRender'];
    /**
     * {@inheritDoc  @sisense/sdk-ui!FunnelChartProps.onDataReady}
     *
     * @category Callbacks
     */
    dataReady: FunnelChartProps['dataReady'];
    /**
     * {@inheritDoc @sisense/sdk-ui!FunnelChartProps.onDataPointClick}
     *
     * @category Callbacks
     */
    dataPointClick: EventEmitter<DataPointEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!FunnelChartProps.onDataPointContextMenu}
     *
     * @category Callbacks
     */
    dataPointContextMenu: EventEmitter<DataPointEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!FunnelChartProps.onDataPointsSelected}
     *
     * @category Callbacks
     */
    dataPointsSelect: EventEmitter<DataPointsEvent>;
    /** @internal */
    chartType: ChartType;
    static ɵfac: i0.ɵɵFactoryDeclaration<FunnelChartComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<FunnelChartComponent, "csdk-funnel-chart", never, { "dataSet": "dataSet"; "dataOptions": "dataOptions"; "filters": "filters"; "highlights": "highlights"; "styleOptions": "styleOptions"; "beforeRender": "beforeRender"; "dataReady": "dataReady"; }, { "dataPointClick": "dataPointClick"; "dataPointContextMenu": "dataPointContextMenu"; "dataPointsSelect": "dataPointsSelect"; }, never, never, false, never>;
}
