import { EventEmitter } from '@angular/core';
import { type LineChartProps as LineChartPropsPreact } from '@sisense/sdk-ui-preact';
import { type ChartType } from '../../sdk-ui-core-exports';
import { RegularChartEventProps, WithoutPreactChartEventProps } from '../../types/chart-event-props';
import { DataPointEvent, DataPointsEvent } from '../../types/data-point';
import * as i0 from "@angular/core";
/**
 * Props of the {@link LineChartComponent}.
 */
export interface LineChartProps extends WithoutPreactChartEventProps<LineChartPropsPreact>, RegularChartEventProps {
}
/**
 * A component displaying data as a series of points connected by a line. Used to show trends or changes over time.
 *
 * @example
 * ```html
 *    <csdk-line-chart
 *      [dataSet]="chart.dataSet"
 *      [dataOptions]="chart.dataOptions"
 *      [highlights]="filters"
 *      [beforeRender]="onBeforeRender"
 *      (dataPointClick)="logArguments($event)"
 *      (dataPointContextMenu)="logArguments($event)"
 *      (dataPointsSelect)="logArguments($event)"
 *    />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory, Filter } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';
import type { ChartType } from '@sisense/sdk-ui-angular';
@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  chart = {
    chartType: 'column' as ChartType,
    dataSet: DM.DataSource,
    dataOptions: {
      category: [DM.Divisions.Divison_name],
      value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
      breakBy: [],
    },
  };

  onBeforeRender(options: any) {
    console.log('beforeRender');
    console.log(options);
    return options;
  }

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-line-chart-example.png" width="800px" />
 * @group Charts
 */
export declare class LineChartComponent {
    /**
     * {@inheritDoc @sisense/sdk-ui!LineChartProps.dataSet}
     *
     * @category Data
     */
    dataSet: LineChartProps['dataSet'];
    /**
     * {@inheritDoc @sisense/sdk-ui!LineChartProps.dataOptions}
     *
     * @category Data
     */
    dataOptions: LineChartProps['dataOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!LineChartProps.filters}
     *
     * @category Data
     */
    filters: LineChartProps['filters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!LineChartProps.highlights}
     *
     * @category Data
     */
    highlights: LineChartProps['highlights'];
    /**
     * {@inheritDoc @sisense/sdk-ui!LineChartProps.styleOptions}
     *
     * @category Chart
     */
    styleOptions: LineChartProps['styleOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!LineChartProps.onBeforeRender}
     *
     * @category Callbacks
     */
    beforeRender: LineChartProps['beforeRender'];
    /**
     * {@inheritDoc  @sisense/sdk-ui!LineChartProps.onDataReady}
     *
     * @category Callbacks
     */
    dataReady: LineChartProps['dataReady'];
    /**
     * {@inheritDoc @sisense/sdk-ui!LineChartProps.onDataPointClick}
     *
     * @category Callbacks
     */
    dataPointClick: EventEmitter<DataPointEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!LineChartProps.onDataPointContextMenu}
     *
     * @category Callbacks
     */
    dataPointContextMenu: EventEmitter<DataPointEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!LineChartProps.onDataPointsSelected}
     *
     * @category Callbacks
     */
    dataPointsSelect: EventEmitter<DataPointsEvent>;
    /** @internal */
    chartType: ChartType;
    static ɵfac: i0.ɵɵFactoryDeclaration<LineChartComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<LineChartComponent, "csdk-line-chart", never, { "dataSet": "dataSet"; "dataOptions": "dataOptions"; "filters": "filters"; "highlights": "highlights"; "styleOptions": "styleOptions"; "beforeRender": "beforeRender"; "dataReady": "dataReady"; }, { "dataPointClick": "dataPointClick"; "dataPointContextMenu": "dataPointContextMenu"; "dataPointsSelect": "dataPointsSelect"; }, never, never, false, never>;
}
