import { EventEmitter } from '@angular/core';
import { type PieChartProps as PieChartPropsPreact } from '@sisense/sdk-ui-preact';
import { type ChartType } from '../../sdk-ui-core-exports';
import { RegularChartEventProps, WithoutPreactChartEventProps } from '../../types/chart-event-props';
import { DataPointEvent, DataPointsEvent } from '../../types/data-point';
import * as i0 from "@angular/core";
/**
 * Props of the {@link PieChartComponent}.
 */
export interface PieChartProps extends WithoutPreactChartEventProps<PieChartPropsPreact>, RegularChartEventProps {
}
/**
 * A component representing data in a circular graph with the data shown as slices of a whole,
 * with each slice representing a proportion of the total.
 *
 * @example
 * ```html
 *    <csdk-pie-chart
 *      [dataSet]="chart.dataSet"
 *      [dataOptions]="chart.dataOptions"
 *      [highlights]="filters"
 *      [beforeRender]="onBeforeRender"
 *      (dataPointClick)="logArguments($event)"
 *      (dataPointContextMenu)="logArguments($event)"
 *      (dataPointsSelect)="logArguments($event)"
 *    />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';
import type { ChartType } from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  chart = {
    chartType: 'column' as ChartType,
    dataSet: DM.DataSource,
    dataOptions: {
      category: [DM.Divisions.Divison_name],
      value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
      breakBy: [],
    },
  };

  onBeforeRender(options: any) {
    console.log('beforeRender');
    console.log(options);
    return options;
  }

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-pie-chart-example.png" width="800px" />
 * @group Charts
 */
export declare class PieChartComponent {
    /**
     * {@inheritDoc @sisense/sdk-ui!PieChartProps.dataSet}
     *
     * @category Data
     */
    dataSet: PieChartProps['dataSet'];
    /**
     * {@inheritDoc @sisense/sdk-ui!PieChartProps.dataOptions}
     *
     * @category Data
     */
    dataOptions: PieChartProps['dataOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!PieChartProps.filters}
     *
     * @category Data
     */
    filters: PieChartProps['filters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!PieChartProps.highlights}
     *
     * @category Data
     */
    highlights: PieChartProps['highlights'];
    /**
     * {@inheritDoc @sisense/sdk-ui!PieChartProps.styleOptions}
     *
     * @category Chart
     */
    styleOptions: PieChartProps['styleOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!PieChartProps.onBeforeRender}
     *
     * @category Callbacks
     */
    beforeRender: PieChartProps['beforeRender'];
    /**
     * {@inheritDoc  @sisense/sdk-ui!PieChartProps.onDataReady}
     *
     * @category Callbacks
     */
    dataReady: PieChartProps['dataReady'];
    /**
     * {@inheritDoc @sisense/sdk-ui!PieChartProps.onDataPointClick}
     *
     * @category Callbacks
     */
    dataPointClick: EventEmitter<DataPointEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!PieChartProps.onDataPointContextMenu}
     *
     * @category Callbacks
     */
    dataPointContextMenu: EventEmitter<DataPointEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!PieChartProps.onDataPointsSelected}
     *
     * @category Callbacks
     */
    dataPointsSelect: EventEmitter<DataPointsEvent>;
    /** @internal */
    chartType: ChartType;
    static ɵfac: i0.ɵɵFactoryDeclaration<PieChartComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PieChartComponent, "csdk-pie-chart", never, { "dataSet": "dataSet"; "dataOptions": "dataOptions"; "filters": "filters"; "highlights": "highlights"; "styleOptions": "styleOptions"; "beforeRender": "beforeRender"; "dataReady": "dataReady"; }, { "dataPointClick": "dataPointClick"; "dataPointContextMenu": "dataPointContextMenu"; "dataPointsSelect": "dataPointsSelect"; }, never, never, false, never>;
}
