import { EventEmitter } from '@angular/core';
import { type SunburstChartProps as SunburstChartPropsPreact } from '@sisense/sdk-ui-preact';
import { type ChartType } from '../../sdk-ui-core-exports';
import { RegularChartEventProps, WithoutPreactChartEventProps } from '../../types/chart-event-props';
import { DataPointEvent, DataPointsEvent } from '../../types/data-point';
import * as i0 from "@angular/core";
/**
 * Props of the {@link SunburstChartComponent}.
 */
export interface SunburstChartProps extends WithoutPreactChartEventProps<SunburstChartPropsPreact>, RegularChartEventProps {
}
/**
 * A component displaying hierarchical data in the form of nested slices.
 * This type of chart can be used instead of a pie chart for comparing a large number of categories and sub-categories.
 *
 * @example
 * ```html
 *    <csdk-sunburst-chart
 *      [dataSet]="chart.dataSet"
 *      [dataOptions]="chart.dataOptions"
 *      [highlights]="filters"
 *      [beforeRender]="onBeforeRender"
 *      (dataPointClick)="logArguments($event)"
 *      (dataPointContextMenu)="logArguments($event)"
 *      (dataPointsSelect)="logArguments($event)"
 *    />
 * ```
 * ```ts
import { Component } from '@angular/core';
import { measureFactory, filterFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';
import type { ChartType } from '@sisense/sdk-ui-angular';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {
  DM = DM;
  filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
  chart = {
    chartType: 'column' as ChartType,
    dataSet: DM.DataSource,
    dataOptions: {
      category: [DM.Divisions.Divison_name],
      value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
      breakBy: [],
    },
  };

  onBeforeRender(options: any) {
    console.log('beforeRender');
    console.log(options);
    return options;
  }

  logArguments(...args: any[]) {
    console.log(args);
  }
}
 * ```
 * <img src="media://angular-sunburst-chart-example.png" width="800px" />
 * @group Charts
 */
export declare class SunburstChartComponent {
    /**
     * {@inheritDoc @sisense/sdk-ui!SunburstChartProps.dataSet}
     *
     * @category Data
     */
    dataSet: SunburstChartProps['dataSet'];
    /**
     * {@inheritDoc @sisense/sdk-ui!SunburstChartProps.dataOptions}
     *
     * @category Chart
     */
    dataOptions: SunburstChartProps['dataOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!SunburstChartProps.filters}
     *
     * @category Data
     */
    filters: SunburstChartProps['filters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!SunburstChartProps.highlights}
     *
     * @category Data
     */
    highlights: SunburstChartProps['highlights'];
    /**
     * {@inheritDoc @sisense/sdk-ui!SunburstChartProps.styleOptions}
     *
     * @category Chart
     */
    styleOptions: SunburstChartProps['styleOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!SunburstChartProps.onBeforeRender}
     *
     * @category Callbacks
     */
    beforeRender: SunburstChartProps['beforeRender'];
    /**
     * {@inheritDoc  @sisense/sdk-ui!SunburstChartProps.onDataReady}
     *
     * @category Callbacks
     */
    dataReady: SunburstChartProps['dataReady'];
    /**
     * {@inheritDoc @sisense/sdk-ui!SunburstChartProps.onDataPointClick}
     *
     * @category Callbacks
     */
    dataPointClick: EventEmitter<DataPointEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!SunburstChartProps.onDataPointContextMenu}
     *
     * @category Callbacks
     */
    dataPointContextMenu: EventEmitter<DataPointEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!SunburstChartProps.onDataPointsSelected}
     *
     * @category Callbacks
     */
    dataPointsSelect: EventEmitter<DataPointsEvent>;
    /** @internal */
    chartType: ChartType;
    static ɵfac: i0.ɵɵFactoryDeclaration<SunburstChartComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SunburstChartComponent, "csdk-sunburst-chart", never, { "dataSet": "dataSet"; "dataOptions": "dataOptions"; "filters": "filters"; "highlights": "highlights"; "styleOptions": "styleOptions"; "beforeRender": "beforeRender"; "dataReady": "dataReady"; }, { "dataPointClick": "dataPointClick"; "dataPointContextMenu": "dataPointContextMenu"; "dataPointsSelect": "dataPointsSelect"; }, never, never, false, never>;
}
