import { AfterViewInit, ElementRef, OnChanges, OnDestroy } from '@angular/core';
import { type DashboardProps as DashboardPropsPreact } from '@sisense/sdk-ui-preact';
import { PluginsService } from '../../services/plugins.service';
import { SisenseContextService } from '../../services/sisense-context.service';
import { ThemeService } from '../../services/theme.service';
import type { DashboardConfig } from '../../types';
import { WidgetProps } from '../widgets/widget.component';
import * as i0 from "@angular/core";
/**
 * Props of the {@link DashboardComponent}.
 */
export interface DashboardProps extends Omit<DashboardPropsPreact, 'widgets'> {
    /**
     * {@inheritDoc @sisense/sdk-ui!DashboardProps.config}
     */
    config?: DashboardConfig;
    /**
     * {@inheritDoc @sisense/sdk-ui!DashboardProps.widgets}
     */
    widgets: WidgetProps[];
}
/**
 * An Angular component used for easily rendering a dashboard created in Sisense Fusion.
 *
 * **Note:** Dashboard and Widget extensions based on JS scripts and add-ons in Fusion – for example, Blox and Jump To Dashboard – are not supported.
 *
 * @example
 * ```html
 * <csdk-dashboard
 *  *ngIf="dashboard"
 *  [title]="dashboard.title"
 *  [layoutOptions]="dashboard.layoutOptions"
 *  [widgets]="dashboard.widgets"
 *  [filters]="dashboard.filters"
 *  [defaultDataSource]="dashboard.defaultDataSource"
 *  [widgetsOptions]="dashboard.widgetsOptions"
 * />
 * ```
 *
 * ```ts
 * import { Component } from '@angular/core';
 * import {
 *   type DashboardProps,
 *   DashboardService,
 *   dashboardModelTranslator,
 * } from '@sisense/sdk-ui-angular';
 *
 * @Component({
 *  selector: 'app-dashboard',
 *  templateUrl: './dashboard.component.html',
 *  styleUrls: ['./dashboard.component.scss'],
 * })
 * export class DashboardComponent {
 *
 *  dashboard: DashboardProps | null = null;
 *
 *  constructor(private dashboardService: DashboardService) {}
 *
 *  async ngOnInit(): Promise<void> {
 *    const dashboardModel = await this.dashboardService.getDashboardModel('your-dashboard-oid', { includeWidgets: true, includeFilters: true });
 *    this.dashboard = dashboardModelTranslator.toDashboardProps(dashboardModel);
 *  }
 * ```
 *
 * To learn more about this and related dashboard components,
 * see [Embedded Dashboards](/guides/sdk/guides/dashboards/index.html).
 * @group Dashboards
 */
export declare class DashboardComponent implements AfterViewInit, OnChanges, OnDestroy {
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService;
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService;
    /**
     * Plugin service
     *
     * @internal
     * @category Constructor
     */
    pluginService: PluginsService;
    /**
     * @internal
     */
    preactRef: ElementRef<HTMLDivElement>;
    /**
     * {@inheritDoc @sisense/sdk-ui!DashboardProps.title}
     */
    title: DashboardProps['title'];
    /**
     * {@inheritDoc @sisense/sdk-ui!DashboardProps.layoutOptions}
     */
    layoutOptions: DashboardProps['layoutOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!DashboardProps.config}
     */
    config: DashboardProps['config'];
    /**
     * {@inheritDoc @sisense/sdk-ui!DashboardProps.widgets}
     */
    widgets: DashboardProps['widgets'];
    /**
     * {@inheritDoc @sisense/sdk-ui!DashboardProps.filters}
     */
    filters: DashboardProps['filters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!DashboardProps.defaultDataSource}
     */
    defaultDataSource: DashboardProps['defaultDataSource'];
    /**
     * {@inheritDoc @sisense/sdk-ui!DashboardProps.widgetsOptions}
     */
    widgetsOptions: DashboardProps['widgetsOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!DashboardProps.styleOptions}
     */
    styleOptions: DashboardProps['styleOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!DashboardProps.tabbersOptions}
     *
     * @internal
     */
    tabbersOptions: DashboardProps['tabbersOptions'];
    private componentAdapter;
    /**
     * Constructor for the `Dashboard` component.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService, 
    /**
     * Plugin service
     *
     * @internal
     * @category Constructor
     */
    pluginService: PluginsService);
    /**
     * @internal
     */
    ngAfterViewInit(): void;
    /**
     * @internal
     */
    ngOnChanges(): void;
    private getPreactComponentProps;
    /**
     * @internal
     */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DashboardComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DashboardComponent, "csdk-dashboard", never, { "title": "title"; "layoutOptions": "layoutOptions"; "config": "config"; "widgets": "widgets"; "filters": "filters"; "defaultDataSource": "defaultDataSource"; "widgetsOptions": "widgetsOptions"; "styleOptions": "styleOptions"; "tabbersOptions": "tabbersOptions"; }, {}, never, never, false, never>;
}
