import { AfterViewInit, ElementRef, EventEmitter, OnChanges, OnDestroy } from '@angular/core';
import { type CriteriaFilterTileProps as CriteriaFilterTilePropsPreact } from '@sisense/sdk-ui-preact';
import { SisenseContextService } from '../../services/sisense-context.service';
import { ThemeService } from '../../services/theme.service';
import type { Arguments, ArgumentsAsObject } from '../../types/utility-types';
import * as i0 from "@angular/core";
/**
 * Props of the {@link CriteriaFilterTileComponent}.
 */
export interface CriteriaFilterTileProps extends Omit<CriteriaFilterTilePropsPreact, 'onUpdate'> {
    filterChange?: (filter: Arguments<CriteriaFilterTilePropsPreact['onUpdate']>[0]) => void;
}
/**
 * Criteria Filter Tile Component
 *
 * @example
 * ```html
 *     <csdk-criteria-filter-tile
 *       [title]="criteriaFilterTileProps.title"
 *       [filter]="criteriaFilterTileProps.filter"
 *       (filterChange)="criteriaFilterTileProps.setFilter($event)"
 *     />
 * ```
 * ```ts
 * import { Component } from '@angular/core';
 * import { Filter, filterFactory } from '@sisense/sdk-data';
 * import * as DM from '../../assets/sample-healthcare-model';
 *
 * @Component({
 *   selector: 'app-filters',
 *   templateUrl: './filters.component.html',
 *   styleUrls: ['./filters.component.scss'],
 * })
 * export class FiltersComponent {
 *   DM = DM;
 *   title: 'Room Number',
 *   filter: filterFactory.lessThan(DM.Rooms.Room_number, 200) ,
 *   setFilter({ filter }: { filter: Filter | null }) {
 *     console.log(filter);
 *     if (filter) {
 *       this.filter = filter ;
 *     }
 *   },
 * }
 * ```
 * <img src="media://angular-criteria-filter-tile-example.png" width="400px" />
 * @group Filter Tiles
 */
export declare class CriteriaFilterTileComponent implements AfterViewInit, OnChanges, OnDestroy {
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService;
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService;
    /**
     * @internal
     */
    preactRef: ElementRef<HTMLDivElement>;
    /**
     * {@inheritDoc @sisense/sdk-ui!CriteriaFilterTileProps.title}
     */
    title: CriteriaFilterTileProps['title'];
    /**
     * {@inheritDoc @sisense/sdk-ui!CriteriaFilterTileProps.filter}
     */
    filter: CriteriaFilterTileProps['filter'];
    /**
     * {@inheritDoc @sisense/sdk-ui!CriteriaFilterTileProps.arrangement}
     */
    arrangement: CriteriaFilterTileProps['arrangement'];
    /**
     * {@inheritDoc @sisense/sdk-ui!CriteriaFilterTileProps.measures}
     */
    measures: CriteriaFilterTileProps['measures'];
    /** @internal */
    tileDesignOptions: CriteriaFilterTileProps['tileDesignOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!CriteriaFilterTileProps.onUpdate}
     */
    filterChange: EventEmitter<ArgumentsAsObject<(filter: import("@sisense/sdk-data").Filter) => void, ["filter"]>>;
    private componentAdapter;
    /**
     * Constructor for the `CriteriaFilterTileComponent`.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService);
    /**
     * @internal
     */
    ngAfterViewInit(): void;
    /**
     * @internal
     */
    ngOnChanges(): void;
    private getPreactComponentProps;
    /**
     * @internal
     */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<CriteriaFilterTileComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CriteriaFilterTileComponent, "csdk-criteria-filter-tile", never, { "title": "title"; "filter": "filter"; "arrangement": "arrangement"; "measures": "measures"; "tileDesignOptions": "tileDesignOptions"; }, { "filterChange": "filterChange"; }, never, never, false, never>;
}
