import { AfterViewInit, ElementRef, EventEmitter, OnChanges, OnDestroy } from '@angular/core';
import { type DateRangeFilterTileProps as DateRangeFilterTilePropsPreact } from '@sisense/sdk-ui-preact';
import { SisenseContextService } from '../../services/sisense-context.service';
import { ThemeService } from '../../services/theme.service';
import type { Arguments, ArgumentsAsObject } from '../../types/utility-types';
import * as i0 from "@angular/core";
/**
 * Props of the {@link DateRangeFilterTileComponent}.
 */
export interface DateRangeFilterTileProps extends Omit<DateRangeFilterTilePropsPreact, 'onChange'> {
    filterChange?: (filter: Arguments<DateRangeFilterTilePropsPreact['onChange']>[0]) => void;
}
/**
 * Date Range Filter Tile Component
 *
 * @example
 * ```html
 * <csdk-date-range-filter-tile
 *       [title]="dateRangeFilterTileProps.title"
 *       [attribute]="dateRangeFilterTileProps.attribute"
 *       [filter]="dateRangeFilterTileProps.filter"
 *       (filterChange)="dateRangeFilterTileProps.setFilter($event)"
 *     />
 * ```
 * ```ts
 * import { Component } from '@angular/core';
 * import { Filter, filterFactory } from '@sisense/sdk-data';
 * import * as DM from '../../assets/sample-healthcare-model';
 *
 * @Component({
 *   selector: 'app-filters',
 *   templateUrl: './filters.component.html',
 *   styleUrls: ['./filters.component.scss'],
 * })
 * export class FiltersComponent {
 *   DM = DM;

 *   dateRangeFilterTileProps = {
 *     title: 'Range Filter',
 *     attribute: DM.ER.Date.Years,
 *     filter: filterFactory.dateRange(DM.ER.Date.Years),
 *     setFilter({ filter }: { filter: Filter | null }) {
 *       console.log(filter);
 *       if (filter) {
 *         this.filter = filter;
 *       }
 *     },
 *   };
 * }
 * ```
 * <img src="media://angular-date-range-filter-tile-example.png" width="600px" />
 * @group Filter Tiles
 */
export declare class DateRangeFilterTileComponent implements AfterViewInit, OnChanges, OnDestroy {
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService;
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService;
    /**
     * @internal
     */
    preactRef: ElementRef<HTMLDivElement>;
    /**
     * {@inheritDoc @sisense/sdk-ui!DateRangeFilterTileProps.title}
     */
    title: DateRangeFilterTileProps['title'];
    /**
     * {@inheritDoc @sisense/sdk-ui!DateRangeFilterTileProps.attribute}
     */
    attribute: DateRangeFilterTileProps['attribute'];
    /**
     * {@inheritDoc @sisense/sdk-ui!DateRangeFilterTileProps.dataSource}
     */
    dataSource: DateRangeFilterTileProps['dataSource'];
    /**
     * {@inheritDoc @sisense/sdk-ui!DateRangeFilterTileProps.filter}
     */
    filter: DateRangeFilterTileProps['filter'];
    /**
     * {@inheritDoc @sisense/sdk-ui!DateRangeFilterTileProps.earliestDate}
     */
    earliestDate: DateRangeFilterTileProps['earliestDate'];
    /**
     * {@inheritDoc @sisense/sdk-ui!DateRangeFilterTileProps.lastDate}
     */
    lastDate: DateRangeFilterTileProps['lastDate'];
    /**
     * {@inheritDoc @sisense/sdk-ui!DateRangeFilterTileProps.onChange}
     */
    filterChange: EventEmitter<ArgumentsAsObject<(filter: import("@sisense/sdk-data").Filter) => void, ["filter"]>>;
    private componentAdapter;
    /**
     * Constructor for the `DateRangeFilterTileComponent`.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService);
    /**
     * @internal
     */
    ngAfterViewInit(): void;
    /**
     * @internal
     */
    ngOnChanges(): void;
    private getPreactComponentProps;
    /**
     * @internal
     */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DateRangeFilterTileComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DateRangeFilterTileComponent, "csdk-date-range-filter-tile", never, { "title": "title"; "attribute": "attribute"; "dataSource": "dataSource"; "filter": "filter"; "earliestDate": "earliestDate"; "lastDate": "lastDate"; }, { "filterChange": "filterChange"; }, never, never, false, never>;
}
