import { AfterViewInit, ElementRef, EventEmitter, OnChanges, OnDestroy } from '@angular/core';
import { type FilterTileProps as FilterTilePropsPreact } from '@sisense/sdk-ui-preact';
import { SisenseContextService } from '../../services/sisense-context.service';
import { ThemeService } from '../../services/theme.service';
import type { BaseFilterTileEventProps, FilterChangeEvent, FilterEditEvent } from '../../types';
import * as i0 from "@angular/core";
/**
 * Props of the {@link FilterTileComponent}.
 */
export interface FilterTileProps extends Omit<FilterTilePropsPreact, 'onChange' | 'onEdit' | 'onDelete'>, BaseFilterTileEventProps {
}
/**
 * UI component that renders a filter tile based on filter type
 *
 * @example
 * Here’s how to render a filter model as a filter tile.
 *
 * ```html
<!--Component HTML template in example.component.html-->
<csdk-filter-tile
  [filter]="filterTileProps.filter"
  (filterChange)="filterTileProps.filterChange($event)"
/>
 * ```
 *
 * ```ts
// Component behavior in example.component.ts
import { Component } from '@angular/core';
import { type FilterTileProps } from '@sisense/sdk-ui-angular';
import { filterFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-healthcare-model';

@Component({
  selector: 'example',
  templateUrl: './example.component.html',
  styleUrls: ['./example.component.scss'],
})
export class ExampleComponent {
  filterTileProps: FilterTileProps = {
    filter: filterFactory.members(DM.ER.Date.Years, ['2013-01-01T00:00:00']),
    filterChange({ filter }) {
      if (filter) {
        this.filter = filter;
      }
    },
  };
}
 * ```
 * <img src="media://angular-member-filter-tile-example.png" width="225px" />
 * @group Filter Tiles
 * @shortDescription Facade component rendering a filter tile based on filter type
 */
export declare class FilterTileComponent implements AfterViewInit, OnChanges, OnDestroy {
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService;
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService;
    /**
     * @internal
     */
    preactRef: ElementRef<HTMLDivElement>;
    /**
     * {@inheritDoc @sisense/sdk-ui!FilterTileProps.filter}
     */
    filter: FilterTileProps['filter'];
    /**
     * {@inheritDoc @sisense/sdk-ui!FilterTileProps.defaultDataSource}
     */
    defaultDataSource: FilterTileProps['defaultDataSource'];
    /**
     * {@inheritDoc FilterTileProps.filterChange}
     */
    filterChange: EventEmitter<FilterChangeEvent>;
    /**
     * {@inheritDoc FilterTileProps.filterEdit}
     */
    filterEdit: EventEmitter<FilterEditEvent>;
    /**
     * {@inheritDoc FilterTileProps.filterDelete}
     */
    filterDelete: EventEmitter<void>;
    private componentAdapter;
    /**
     * Constructor for the `FilterTileComponent`.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService);
    /**
     * @internal
     */
    ngAfterViewInit(): void;
    /**
     * @internal
     */
    ngOnChanges(): void;
    private getPreactComponentProps;
    /**
     * @internal
     */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<FilterTileComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<FilterTileComponent, "csdk-filter-tile", never, { "filter": "filter"; "defaultDataSource": "defaultDataSource"; }, { "filterChange": "filterChange"; "filterEdit": "filterEdit"; "filterDelete": "filterDelete"; }, never, never, false, never>;
}
