import { AfterViewInit, ElementRef, EventEmitter, OnChanges, OnDestroy } from '@angular/core';
import { type ChartWidgetProps as ChartWidgetPropsPreact } from '@sisense/sdk-ui-preact';
import { SisenseContextService } from '../../services/sisense-context.service';
import { ThemeService } from '../../services/theme.service';
import { ChartEventProps, WithoutPreactChartEventProps } from '../../types/chart-event-props';
import { ChartDataPointClickEvent, ChartDataPointContextMenuEvent, ChartDataPointsEvent } from '../../types/data-point';
import * as i0 from "@angular/core";
/**
 * Props of the {@link ChartWidgetComponent}.
 */
export interface ChartWidgetProps extends WithoutPreactChartEventProps<ChartWidgetPropsPreact>, ChartEventProps {
}
/**
 * The Chart Widget component extending {@link ChartComponent} to support widget style options.
 *
 * @example
 * ```html
 * <csdk-chart-widget
 *   [chartType]="chartWidget.chartType"
 *   [dataSource]="chartWidget.dataSource"
 *   [dataOptions]="chartWidget.dataOptions"
 *   [highlights]="filters"
 *   [title]="chartWidget.title"
 *   [description]="chartWidget.description"
 *   [beforeRender]="onBeforeRender"
 *   (dataPointClick)="logArguments($event)"
 *   (dataPointContextMenu)="logArguments($event)"
 *   (dataPointsSelect)="logArguments($event)"
 * />
 * ```
 * ```ts
 * import { Component } from '@angular/core';
 * import { ChartType } from '@sisense/sdk-ui-angular';
 * import { filterFactory } from '@sisense/sdk-data';
 * import * as DM from '../../assets/sample-healthcare-model';
 *
 * @Component({
 *   selector: 'app-widgets',
 *   templateUrl: './widgets.component.html',
 *   styleUrls: ['./widgets.component.scss'],
 * })
 * export class WidgetsComponent {
 *   filters = [filterFactory.members(DM.Divisions.Divison_name, ['Cardiology', 'Neurology'])];
 *   chartWidget = {
 *     chartType: 'column' as ChartType,
 *     dataSource: DM.DataSource,
 *     dataOptions: {
 *       category: [DM.Divisions.Divison_name],
 *       value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
 *       breakBy: [],
 *     },
 *     title: 'Chart Title',
 *     description: 'Chart Description',
 *   };
 *  logArguments(...args: any[]) {
 *   console.log(args);
 * }
 *
 * onBeforeRender(options: any) {
 *   console.log('beforeRender');
 *   console.log(options);
 *   return options;
 * }
 *
 * }
 * ```
 * <img src="media://angular-chart-widget-example.png" width="500px" />
 * @group Dashboards
 */
export declare class ChartWidgetComponent implements AfterViewInit, OnChanges, OnDestroy {
    private sisenseContextService;
    private themeService;
    /** @internal */
    preactRef: ElementRef<HTMLDivElement>;
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.chartType}
     *
     * @category Chart
     */
    chartType: ChartWidgetProps['chartType'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.dataSource}
     *
     * @category Data
     */
    dataSource: ChartWidgetProps['dataSource'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.dataOptions}
     *
     * @category Chart
     */
    dataOptions: ChartWidgetProps['dataOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.filters}
     *
     * @category Data
     */
    filters: ChartWidgetProps['filters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.highlights}
     *
     * @category Data
     */
    highlights: ChartWidgetProps['highlights'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.styleOptions}
     *
     * @category Widget
     */
    styleOptions: ChartWidgetProps['styleOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.drilldownOptions}
     *
     * @category Widget
     * @internal
     */
    drilldownOptions: ChartWidgetProps['drilldownOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.title}
     *
     * @category Widget
     */
    title: ChartWidgetProps['title'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.description}
     *
     * @category Widget
     */
    description: ChartWidgetProps['description'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.highlightSelectionDisabled}
     *
     * @category Widget
     */
    highlightSelectionDisabled: ChartWidgetProps['highlightSelectionDisabled'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.onBeforeRender}
     *
     * @category Callbacks
     */
    beforeRender: ChartWidgetProps['beforeRender'];
    /**
     * {@inheritDoc  @sisense/sdk-ui!ChartWidgetProps.onDataReady}
     *
     * @category Callbacks
     */
    dataReady: ChartWidgetProps['dataReady'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.onDataPointClick}
     *
     * @category Callbacks
     */
    dataPointClick: EventEmitter<ChartDataPointClickEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.onDataPointContextMenu}
     *
     * @category Callbacks
     */
    dataPointContextMenu: EventEmitter<ChartDataPointContextMenuEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.onDataPointsSelected}
     *
     * @category Callbacks
     */
    dataPointsSelect: EventEmitter<ChartDataPointsEvent>;
    private componentAdapter;
    constructor(sisenseContextService: SisenseContextService, themeService: ThemeService);
    /** @internal */
    ngAfterViewInit(): void;
    /** @internal */
    ngOnChanges(): void;
    private getPreactComponentProps;
    /** @internal */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ChartWidgetComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ChartWidgetComponent, "csdk-chart-widget", never, { "chartType": "chartType"; "dataSource": "dataSource"; "dataOptions": "dataOptions"; "filters": "filters"; "highlights": "highlights"; "styleOptions": "styleOptions"; "drilldownOptions": "drilldownOptions"; "title": "title"; "description": "description"; "highlightSelectionDisabled": "highlightSelectionDisabled"; "beforeRender": "beforeRender"; "dataReady": "dataReady"; }, { "dataPointClick": "dataPointClick"; "dataPointContextMenu": "dataPointContextMenu"; "dataPointsSelect": "dataPointsSelect"; }, never, never, false, never>;
}
