import { AfterViewInit, ElementRef, EventEmitter, OnChanges, OnDestroy } from '@angular/core';
import { type ComponentRenderer, type ContextMenuProps, type CustomDrilldownResult as CustomDrilldownResultBase, DrilldownBreadcrumbsProps, type DrilldownWidgetProps } from '@sisense/sdk-ui-preact';
import { SisenseContextService } from '../../services/sisense-context.service';
import { ThemeService } from '../../services/theme.service';
import * as i0 from "@angular/core";
export type CustomDrilldownResult = CustomDrilldownResultBase & {
    breadcrumbsComponent?: {
        render: ComponentRenderer;
    };
};
/**
 * An Angular component designed to add drilldown functionality to any type of chart.
 *
 * It acts as a wrapper around a given chart component, enhancing it with drilldown capabilities
 *
 * The widget offers several features including:
 * - A context menu for initiating drilldown actions (can be provided as a custom component)
 * - Breadcrumbs that not only allow for drilldown selection slicing but also
 * provide an option to clear the selection (can be provided as a custom component)
 * - Filters specifically created for drilldown operation
 * - An option to navigate to the next drilldown dimension
 *
 * When an `initialDimension` is specified, the `drilldownDimension` will automatically inherit its value,
 * even before any points on the chart are selected.
 * This allows for complete control over the chart's dimensions to be handed over to the DrilldownWidget
 *
 * @example
 * An example of using the `csdk-drilldown-widget` component to plot a `csdk-column-chart`
 * over the Sample Healthcare data source hosted in a Sisense instance:
 * ```ts
 * // Component behavior in .component.ts
 * chart = {
 *   dataOptions: {
 *     category: [DM.Divisions.Divison_name],
 *     value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
 *     breakBy: [],
 *   },
 *   dataPointContextMenu: ({ point, nativeEvent }: { point: any; nativeEvent: MouseEvent }) => {
 *     this.drilldownResult?.onDataPointsSelected?.([point], nativeEvent);
 *     this.drilldownResult?.onContextMenu({
 *       left: nativeEvent.clientX,
 *       top: nativeEvent.clientY,
 *     });
 *   }
 * }
 *
 * drilldownResult?: CustomDrilldownResult;
 *
 * drilldown = {
 *   drilldownPaths: [DM.Patients.Gender, DM.Admissions.Surgical_Procedure],
 *   initialDimension: DM.Divisions.Divison_name,
 *   drilldownChange: (drilldownResult: CustomDrilldownResult) => {
 *     this.drilldownResult = drilldownResult;
 *     this.chart.dataOptions = {
 *       ...this.chart.dataOptions,
 *       category: [drilldownResult.drilldownDimension]
 *     }
 *   }
 * };
 * ```
 * ```html
 * <!--Component HTML template in .component.html-->
 * <csdk-drilldown-widget
 *   [drilldownPaths]="drilldown.drilldownPaths"
 *   [initialDimension]="drilldown.initialDimension"
 *   (drilldownResultChange)="drilldown.drilldownChange($event)"
 * >
 *   <csdk-column-chart
 *     [dataSet]="DM.DataSource"
 *     [dataOptions]="chart.dataOptions"
 *     [filters]="drilldownResult?.drilldownFilters || []"
 *     (dataPointContextMenu)="chart.dataPointContextMenu($event)"
 *   />
 * </csdk-drilldown-widget>
 * ```
 * <img src="media://angular-drilldown-widget-example.png" width="800px" />
 * @group Drilldown
 */
export declare class DrilldownWidgetComponent implements AfterViewInit, OnChanges, OnDestroy {
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService;
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService;
    /**
     * @internal
     */
    preactRef: ElementRef<HTMLDivElement>;
    /**
     * @internal
     */
    preactContentRef: ElementRef<HTMLDivElement>;
    /**
     * {@inheritDoc @sisense/sdk-ui!DrilldownWidgetProps.drilldownPaths}
     *
     * @category Widget
     */
    drilldownPaths: DrilldownWidgetProps['drilldownPaths'];
    /**
     * {@inheritDoc @sisense/sdk-ui!DrilldownWidgetProps.initialDimension}
     *
     * @category Widget
     */
    initialDimension: DrilldownWidgetProps['initialDimension'];
    /**
     * {@inheritDoc @sisense/sdk-ui!DrilldownWidgetProps.config}
     *
     * @category Widget
     */
    config?: Omit<DrilldownWidgetProps['config'], 'breadcrumbsComponent | contextMenuComponent'> & {
        breadcrumbsComponent?: (drilldownBreadcrumbsProps: DrilldownBreadcrumbsProps) => HTMLDivElement;
        contextMenuComponent?: (contextMenuProps: ContextMenuProps) => HTMLDivElement;
    };
    /**
     * Drilldown result change handler callback
     *
     * @category Callbacks
     */
    drilldownResultChange: EventEmitter<CustomDrilldownResult>;
    private componentAdapter;
    /**
     * Constructor for the `DrilldownWidgetComponent`.
     *
     * @param sisenseContextService - Sisense context service
     * @param themeService - Theme service
     */
    constructor(
    /**
     * Sisense context service
     *
     * @category Constructor
     */
    sisenseContextService: SisenseContextService, 
    /**
     * Theme service
     *
     * @category Constructor
     */
    themeService: ThemeService);
    /**
     * @internal
     */
    ngAfterViewInit(): void;
    /**
     * @internal
     */
    ngOnChanges(): void;
    private getPreactComponentProps;
    /**
     * @internal
     */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<DrilldownWidgetComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<DrilldownWidgetComponent, "csdk-drilldown-widget", never, { "drilldownPaths": "drilldownPaths"; "initialDimension": "initialDimension"; "config": "config"; }, { "drilldownResultChange": "drilldownResultChange"; }, never, ["*"], false, never>;
}
