import { AfterViewInit, ElementRef, OnChanges, OnDestroy } from '@angular/core';
import { type PivotTableWidgetProps as PivotTableWidgetPropsPreact } from '@sisense/sdk-ui-preact';
import { SisenseContextService } from '../../services';
import { ThemeService } from '../../services';
import * as i0 from "@angular/core";
/**
 * Props of the {@link PivotTableWidgetComponent}.
 */
export interface PivotTableWidgetProps extends PivotTableWidgetPropsPreact {
}
/**
 * The Pivot Table Widget component extends the {@link PivotTableComponent} component to support widget features,
 * including a header, widget style options, and more.
 *
 * @example
 * ```html
<csdk-pivot-table-widget
  [dataSource]="pivotProps.dataSource"
  [dataOptions]="pivotProps.dataOptions"
  [filters]="pivotProps.filters"
  [styleOptions]="pivotProps.styleOptions"
  [title]="pivotProps.title"
  [description]="pivotProps.description"
/>
 * ```
 * ```ts
import { Component } from '@angular/core';
import { type PivotTableWidgetProps } from '@sisense/sdk-ui-angular';
import { measureFactory, filterFactory } from '@sisense/sdk-data';
import * as DM from '../../assets/sample-ecommerce';

@Component({
  selector: 'app-analytics',
  templateUrl: './analytics.component.html',
  styleUrls: ['./analytics.component.scss'],
})
export class AnalyticsComponent {

  pivotProps: PivotTableWidgetProps = {
    dataSource: DM.DataSource,
    dataOptions: {
      rows: [
        { column: DM.Category.Category, includeSubTotals: true },
        { column: DM.Commerce.AgeRange, includeSubTotals: true },
        DM.Commerce.Condition,
      ],
      columns: [{ column: DM.Commerce.Gender, includeSubTotals: true }],
      values: [
        measureFactory.sum(DM.Commerce.Cost, 'Total Cost'),
        {
          column: measureFactory.sum(DM.Commerce.Revenue, 'Total Revenue'),
          totalsCalculation: 'sum',
          dataBars: true,
        },
      ],
      grandTotals: { title: 'Grand Total', rows: true, columns: true },
    },
    filters: [filterFactory.members(DM.Commerce.Gender, ['Female', 'Male'])],
    styleOptions: { width: 1400, height: 600, rowsPerPage: 25 },
    title: 'Pivot Table Widget',
    description: 'Pivot Table Widget Description',
  };
}
 * ```
 * <img src="media://angular-pivot-table-widget-example.png" width="800px" />
 * @group Dashboards
 * @beta
 */
export declare class PivotTableWidgetComponent implements AfterViewInit, OnChanges, OnDestroy {
    private sisenseContextService;
    private themeService;
    /** @internal */
    preactRef: ElementRef<HTMLDivElement>;
    /**
     * {@inheritDoc @sisense/sdk-ui!PivotTableWidgetProps.dataSource}
     *
     * @category Data
     */
    dataSource: PivotTableWidgetProps['dataSource'];
    /**
     * {@inheritDoc @sisense/sdk-ui!PivotTableWidgetProps.dataOptions}
     *
     * @category Data
     */
    dataOptions: PivotTableWidgetProps['dataOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!PivotTableWidgetProps.filters}
     *
     * @category Data
     */
    filters: PivotTableWidgetProps['filters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!PivotTableWidgetProps.highlights}
     *
     * @category Data
     */
    highlights: PivotTableWidgetProps['highlights'];
    /**
     * {@inheritDoc @sisense/sdk-ui!PivotTableWidgetProps.styleOptions}
     *
     * @category Representation
     */
    styleOptions: PivotTableWidgetProps['styleOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!PivotTableWidgetProps.title}
     *
     * @category Widget
     */
    title: PivotTableWidgetProps['title'];
    /**
     * {@inheritDoc @sisense/sdk-ui!PivotTableWidgetProps.title}
     *
     * @category Widget
     */
    description: PivotTableWidgetProps['description'];
    private componentAdapter;
    constructor(sisenseContextService: SisenseContextService, themeService: ThemeService);
    /** @internal */
    ngAfterViewInit(): void;
    /** @internal */
    ngOnChanges(): void;
    private getPreactComponentProps;
    /** @internal */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<PivotTableWidgetComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PivotTableWidgetComponent, "csdk-pivot-table-widget", never, { "dataSource": "dataSource"; "dataOptions": "dataOptions"; "filters": "filters"; "highlights": "highlights"; "styleOptions": "styleOptions"; "title": "title"; "description": "description"; }, {}, never, never, false, never>;
}
