import { AfterViewInit, ElementRef, EventEmitter, OnChanges, OnDestroy } from '@angular/core';
import { type BeforeMenuOpenHandler, PluginWidgetProps, type SoftUnion, TextWidgetProps } from '@sisense/sdk-ui-preact';
import { SisenseContextService } from '../../services/sisense-context.service';
import { ThemeService } from '../../services/theme.service';
import { ChartDataPointClickEvent, ChartDataPointContextMenuEvent, ChartDataPointsEvent } from '../../types/data-point';
import { ChartWidgetProps } from './chart-widget.component';
import { PivotTableWidgetProps } from './pivot-table-widget.component';
import * as i0 from "@angular/core";
/**
 * {@inheritDoc @sisense/sdk-ui!WithCommonWidgetProps}
 */
export type WithCommonWidgetProps<BaseWidget, Type> = BaseWidget & {
    /**
     * Unique identifier of the widget within the container component (dashboard)
     *
     */
    readonly id: string;
    /**
     * Widget type
     */
    widgetType: Type;
    /**
     * Optional handler function to process menu options before opening the context menu.
     *
     * @internal
     */
    beforeMenuOpen?: BeforeMenuOpenHandler;
};
/**
 * Props of the {@link WidgetComponent}.
 */
export type WidgetProps = SoftUnion<WithCommonWidgetProps<ChartWidgetProps, 'chart'> | WithCommonWidgetProps<PivotTableWidgetProps, 'pivot'> | WithCommonWidgetProps<TextWidgetProps, 'text'> | WithCommonWidgetProps<PluginWidgetProps, 'plugin'>>;
/**
 * Facade component that renders a widget within a dashboard based on the widget type.
 *
 * @example
 * ```html
<!--Component HTML template in example.component.html-->
<csdk-widget
  [id]="widgetProps.id"
  [title]="widgetProps.title"
  [widgetType]="widgetProps.widgetType"
  [chartType]="widgetProps.chartType"
  [dataSource]="widgetProps.dataSource"
  [dataOptions]="widgetProps.dataOptions"
/>
 * ```
 *
 * ```ts
// Component behavior in example.component.ts
import { Component } from '@angular/core';
import { type WidgetProps } from '@sisense/sdk-ui-angular';

@Component({
  selector: 'example',
  templateUrl: './example.component.html',
  styleUrls: ['./example.component.scss'],
})
export class ExampleComponent {
  widgetProps: WidgetProps = {
    id: 'widget-id',
    widgetType: 'chart',
    chartType: 'column',
    title: 'Widget Title',
    dataSource: DM.DataSource,
    dataOptions: {
      category: [DM.Divisions.Divison_name],
      value: [measureFactory.sum(DM.Admissions.Cost_of_admission)],
      breakBy: [],
    },
  };
}
 * ```
 * <img src="media://angular-chart-widget-example.png" width="500px" />
 * @group Dashboards
 */
export declare class WidgetComponent implements AfterViewInit, OnChanges, OnDestroy {
    private sisenseContextService;
    private themeService;
    /** @internal */
    preactRef: ElementRef<HTMLDivElement>;
    /**
     * Unique identifier of the widget
     *
     * @category Widget
     */
    id: WidgetProps['id'];
    /**
     * Widget type
     *
     * @category Widget
     */
    widgetType: WidgetProps['widgetType'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.chartType}
     *
     * @category Chart
     */
    chartType: WidgetProps['chartType'];
    /**
     * {@inheritDoc @sisense/sdk-ui!PluginWidgetProps.pluginType}
     *
     * @category Widget
     */
    pluginType: WidgetProps['pluginType'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.dataSource}
     *
     * @category Data
     */
    dataSource: WidgetProps['dataSource'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.dataOptions}
     *
     * @category Chart
     */
    dataOptions: WidgetProps['dataOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.filters}
     *
     * @category Data
     */
    filters: WidgetProps['filters'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.highlights}
     *
     * @category Data
     */
    highlights: WidgetProps['highlights'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.styleOptions}
     *
     * @category Widget
     */
    styleOptions: WidgetProps['styleOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.drilldownOptions}
     *
     * @category Widget
     */
    drilldownOptions: WidgetProps['drilldownOptions'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.title}
     *
     * @category Widget
     */
    title: WidgetProps['title'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.description}
     *
     * @category Widget
     */
    description: WidgetProps['description'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.highlightSelectionDisabled}
     *
     * @category Widget
     * @internal
     */
    highlightSelectionDisabled: WidgetProps['highlightSelectionDisabled'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.onBeforeRender}
     *
     * @category Callbacks
     */
    beforeRender: WidgetProps['beforeRender'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.onDataReady}
     *
     * @category Callbacks
     */
    dataReady: WidgetProps['dataReady'];
    /**
     * Optional handler function to process menu options before opening the context menu.
     *
     * @category Callbacks
     * @internal
     */
    beforeMenuOpen: WidgetProps['beforeMenuOpen'];
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.onDataPointClick}
     *
     * @category Callbacks
     */
    dataPointClick: EventEmitter<ChartDataPointClickEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.onDataPointContextMenu}
     *
     * @category Callbacks
     */
    dataPointContextMenu: EventEmitter<ChartDataPointContextMenuEvent>;
    /**
     * {@inheritDoc @sisense/sdk-ui!ChartWidgetProps.onDataPointsSelected}
     *
     * @category Callbacks
     */
    dataPointsSelect: EventEmitter<ChartDataPointsEvent>;
    private componentAdapter;
    constructor(sisenseContextService: SisenseContextService, themeService: ThemeService);
    /** @internal */
    ngAfterViewInit(): void;
    /** @internal */
    ngOnChanges(): void;
    private getPreactComponentProps;
    /** @internal */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<WidgetComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<WidgetComponent, "csdk-widget", never, { "id": "id"; "widgetType": "widgetType"; "chartType": "chartType"; "pluginType": "pluginType"; "dataSource": "dataSource"; "dataOptions": "dataOptions"; "filters": "filters"; "highlights": "highlights"; "styleOptions": "styleOptions"; "drilldownOptions": "drilldownOptions"; "title": "title"; "description": "description"; "highlightSelectionDisabled": "highlightSelectionDisabled"; "beforeRender": "beforeRender"; "dataReady": "dataReady"; "beforeMenuOpen": "beforeMenuOpen"; }, { "dataPointClick": "dataPointClick"; "dataPointContextMenu": "dataPointContextMenu"; "dataPointsSelect": "dataPointsSelect"; }, never, never, false, never>;
}
